@@ -173,7 +173,7 @@ enum { SETTINGS_STATIONS_PAGE, SETTINGS_VISUALS_PAGE, SETTINGS_DISPLAY_PAGE,
 #endif
        ALERTS_PAGE, MAX_SETTINGS_PAGE_NUMBER, ABOUT_PAGE
 };
-enum { SIMPLE_MODE, EXTENDED_MODE };
+enum { SIMPLE_MODE = 3, EXTENDED_MODE, MEDIUM_MODE };
 enum { SHORT_CLICK, LONG_CLICK };
 enum {COLLAPSED_VIEW_MODE, EXPANDED_VIEW_MODE};
 
